<?php
/*
Plugin Name: WPnet.pl Templates plugin
Plugin URI: http://wpnet.pl/blog/wtyczki/wtyczka-wpnet-pl-templates/
Version: 1.0
Author: wpnet.pl
Author URI: http://wpnet.pl
License: GPL2
*/

/* Make sure we don't expose any info if called directly */
if ( !function_exists( 'add_action' ) ) {
	exit;
}

/**
 * WPnet.pl Templates Class.
 */
class wpnet_templates {

	/**
	 * Hook into the appropriate actions when the class is constructed.
	 */
    public function __construct() {
		add_action( 'init', array( $this, 'wpnet_templates_load_textdomain' ) );
		add_action( 'init', array( $this, 'wpnet_templates_register_post_types' ) );
		add_action( 'add_meta_boxes', array( $this, 'wpnet_templates_add_meta_box' ) );
		add_action( 'add_meta_boxes', array( $this, 'wpnet_templates_add_adsense_meta_box' ) );
		add_action( 'save_post', array( $this, 'wpnet_templates_save_custom_meta' ) );
        add_filter( 'the_content', array( $this, 'wpnet_templates_add_content' ), 1 );
    }

	/**
	 * Load plugin textdomain.
	 */
	public function wpnet_templates_load_textdomain() {
		load_plugin_textdomain( 'wpnet-templates', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Register custom post types.
	 */
	function wpnet_templates_register_post_types() {
		$labels = array(
			'name' =>  __( 'WPnet.pl - Templates', 'wpnet-templates'),
			'singular_name' =>  __( 'WPnet.pl - Template', 'wpnet-templates'),
			'menu_name' =>  __( 'WPnet.pl - Templates', 'wpnet-templates'),
			'name_admin_bar' =>  __( 'Templates', 'wpnet-templates'),
			'all_items' =>  __( 'All templates', 'wpnet-templates'),
			'add_new' =>  __( 'Add new', 'wpnet-templates'),
			'add_new_item' =>  __( 'Add new', 'wpnet-templates'),
			'edit_item' =>  __( 'Edit', 'wpnet-templates'),
			'new_item' =>  __( 'New template', 'wpnet-templates'),
			'view_item' =>  __( 'View template', 'wpnet-templates'),
			'search_items' =>  __( 'Search', 'wpnet-templates'),
			'not_found' =>  __( 'Nothing found', 'wpnet-templates'),
			'not_found_in_trash' =>  __( 'Nothing found in trash', 'wpnet-templates'),
		);

		$args = array(
			'labels' => $labels,
			'description' => '',
			'public' => false,
			'show_ui' => true,
			'has_archive' => false,
			'show_in_menu' => true,
			'exclude_from_search' => true,
			'capability_type' => 'post',
			'map_meta_cap' => true,
			'hierarchical' => false,
			'rewrite' => false,
			'query_var' => false,
			'menu_icon' => 'dashicons-welcome-widgets-menus',
			'supports' => array( 'title', 'editor' ),
		);
		register_post_type( 'wpnet-templates', $args );
	}

	/**
	 * Add the meta box container.
	 */
	public function wpnet_templates_add_meta_box() {
		add_meta_box(
			'wpnet-templates-post-type',
			__( 'Template', 'wpnet-templates'),
			array( $this, 'wpnet_templates_meta_box' ),
			'wpnet-templates',
			'normal',
			'high'
		); 
	}
	
	
	/**
	 * Add the adsense meta box container.
	 */
	public function wpnet_templates_add_adsense_meta_box() {
		add_meta_box(
			'wpnet-templates-adsense',
			__( 'AdSense', 'wpnet-templates'),
			array( $this, 'wpnet_templates_adsense_meta_box' ),
			'wpnet-templates',
			'side',
			'low'
		); 
	}
	
	public function wpnet_templates_adsense_meta_box() { ?>
		<p>  
			<script async src="//pagead2.googlesyndication.com/pagead/js/adsbygoogle.js"></script>
			<!-- Templates -->
			<ins class="adsbygoogle"
				 style="display:block"
				 data-ad-client="ca-pub-3108562660523583"
				 data-ad-slot="7927958085"
				 data-ad-format="auto"></ins>
			<script>
			(adsbygoogle = window.adsbygoogle || []).push({});
			</script>
		</p>
	<?php
	}
	
	/**
	 * Render Meta Box content.
	 *
	 * @param WP_Post $post The post object.
	 */
	public function wpnet_templates_meta_box( $post ) {

		/* Add an nonce field so we can check for it later. */
		wp_nonce_field( 'custom_meta_box', 'custom_meta_box_nonce' );

		/* Use get_post_meta to retrieve an existing value from the database.*/
		$wpnet_templates_post_type = get_post_meta( $post->ID, 'wpnet_templates_post_type', true );
		?>
		<p>
			<label for="wpnet_templates_post_type"><?php _e( 'Post type', 'wpnet-templates') ?></label><br/>
			<select name="wpnet_templates_post_type" id="wpnet_templates_post_type">
			<?php
			$post_types = get_post_types( array( 'public' => true ), 'objects' );
			foreach ( $post_types as $post_type ): ?>
				<option value="<?php echo esc_attr( $post_type->name ); ?>"
				<?php
				if ( esc_html($post_type->name) == $wpnet_templates_post_type ) {
					echo ' selected="selected"';
				}
				?>
				><?php echo esc_html( $post_type->label ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		
		<?php
		/* Use get_post_meta to retrieve an existing value from the database. */		$wpnet_templates_location = get_post_meta( $post->ID, 'wpnet_templates_location', true );
		?> 		
		<p>
			<label for="wpnet_templates_location"><?php _e( 'Location', 'wpnet-templates') ?></label><br/>
			
			<select name="wpnet_templates_location" id="wpnet_templates_location">
				<option value="before"
				<?php
				if ( 'before' == $wpnet_templates_location ) {
					echo ' selected="selected"';
				}
				?>
				><?php _e( 'Before post', 'wpnet-templates') ?></option>
				
				<option value="after"
				<?php
				if ( 'after' == $wpnet_templates_location ) {
					echo ' selected="selected"';
				}
				?>
				><?php _e( 'After post', 'wpnet-templates') ?></option>			
			</select>
		</p>
		
		<?php
		/* Use get_post_meta to retrieve an existing value from the database. */
		$wpnet_templates_custom_css = get_post_meta( $post->ID, 'wpnet_templates_custom_css', true );
		?> 		
		<p>
			<label for="wpnet_templates_custom_css"><?php _e( 'Custom css', 'wpnet-templates') ?></label><br/>
			<textarea type="text" name="wpnet_templates_custom_css" id="wpnet_templates_custom_css" rows="9" style="width:100%"><?php echo esc_textarea( $wpnet_templates_custom_css ); ?></textarea>
		</p>
		<?php
	}

	/**
	 * Save the meta when the post is saved.
	 *
	 * @param int $post_id The ID of the post being saved.
	 */
	public function wpnet_templates_save_custom_meta( $post_id ) {

		/*
		 * We need to verify this came from the our screen and with proper authorization,
		 * because save_post can be triggered at other times.
		 */

		/* Check if our nonce is set. */
		if ( ! isset( $_POST['custom_meta_box_nonce'] ) )
			return $post_id;

		$nonce = $_POST['custom_meta_box_nonce'];

		/* Verify that the nonce is valid. */
		if ( ! wp_verify_nonce( $nonce, 'custom_meta_box' ) )
			return $post_id;

		/* If this is an autosave, our form has not been submitted, so we don't want to do anything. */
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;

		/* Check the user's permissions. */
		if ( 'page' == $_POST['post_type'] ) {

			if ( ! current_user_can( 'edit_page', $post_id ) )
				return $post_id;

		} else {

			if ( ! current_user_can( 'edit_post', $post_id ) )
				return $post_id;
		}

		/* OK, its safe for us to save the data now. */

		/* Sanitize the user input. */
		$wpnet_templates_post_type = sanitize_text_field( $_POST['wpnet_templates_post_type'] );
		$wpnet_templates_location = sanitize_text_field( $_POST['wpnet_templates_location'] );
		$wpnet_templates_custom_css = implode( "\n", array_map( 'sanitize_text_field', explode( "\n", $_POST['wpnet_templates_custom_css'] ) ) );

		/* Update the meta field. */
		update_post_meta( $post_id, 'wpnet_templates_post_type', $wpnet_templates_post_type );
		update_post_meta( $post_id, 'wpnet_templates_location', $wpnet_templates_location );
		update_post_meta( $post_id, 'wpnet_templates_custom_css', $wpnet_templates_custom_css );
	}
	
	/**
	 * Add content.
	 */
    public function wpnet_templates_add_content( $content )  {

        if ( is_single( get_the_ID() ) ) {

			/* Get current post type. */
			$current_post_type = get_post_type();

			/* Get list of WPnet.pl Templates */

			/* The Query */
			$the_query = new WP_Query($args = array(
				'post_type' => 'wpnet-templates',
			) );

			/* The Loop */
			if ( $the_query->have_posts() ) {
				while ( $the_query->have_posts() ) {
					$the_query->the_post();

					/* Get post type for add template */
					$post_type_to_add = get_post_meta( get_the_ID(), 'wpnet_templates_post_type', true );
					
					if ( $current_post_type == $post_type_to_add ) {
						
						/* Add custom style */
						$wpnet_templates_custom_css = get_post_meta( get_the_ID(), 'wpnet_templates_custom_css', true );
						if( ! empty( $wpnet_templates_custom_css) ) {
							echo '<style>';
							echo $wpnet_templates_custom_css;
							echo '</style>';
						}

						/* Get location */
						$wpnet_templates_location = get_post_meta( get_the_ID(), 'wpnet_templates_location', true );

						if ( $wpnet_templates_location == 'before' ) {
							$content = '<div class="wpnet-templates">' . get_the_content() . '</div>' . $content;
						} else if ( $wpnet_templates_location == 'after' ){
							$content = $content . '<div class="wpnet-templates">' . get_the_content() . '</div>';
						}
					}
				}
			}
			/* Restore original Post Data */
			wp_reset_postdata();
        }
        return $content;
    }
}
new wpnet_templates();

?>